# OrganisationAdmin

Request object for organisation creation

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**organisation** | **str** | organisation name | 
**id** | **str** | Unique identifier | [optional] [readonly] 
**issuer** | **str** | connect id issuer | [optional] 
**subdomain** | **str** | organisation subdomain | [optional] 
**parent_id** | **str** | parent organisation id | [optional] 
**billing_account_id** | **str** | The billing account id | [optional] 
**product_label_override** | **str** | Override the default product label.  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


